@@ -354,12 +354,13 @@ static void indicator_ng_menu_section_changed(GMenuModel *pMenuSection, gint nPo
         for (guint nSection = 0; nSection < nSections; nSection++)
         {
             GMenuModel *pSection = g_menu_model_get_item_link(pModel, nSection, G_MENU_LINK_SECTION);
+            guint nSubsections = 0;
 
             if (pSection)
             {
                 gchar *sNamespace;
                 gboolean bNamespace = g_menu_model_get_item_attribute(pModel, nSection, G_MENU_ATTRIBUTE_ACTION_NAMESPACE, "s", &sNamespace);
-                guint nSubsections = g_menu_model_get_n_items(pSection);
+                nSubsections = g_menu_model_get_n_items(pSection);
 
                 for (guint nSubsection = 0; nSubsection < nSubsections; nSubsection++)
                 {
@@ -405,7 +406,7 @@ static void indicator_ng_menu_section_changed(GMenuModel *pMenuSection, gint nPo
                 g_object_unref(pSection);
             }
 
-            if (!g_str_equal(self->name, "ayatana-indicator-messages"))
+            if (pSection && nSubsections)
             {
                 nMenuItem++;
             }
@@ -521,19 +522,41 @@ indicator_ng_set_icon_from_variant (IndicatorNg *self,
     }
 }
 
-static void
-indicator_ng_set_label (IndicatorNg *self,
-                        const gchar *label)
+static void indicator_ng_set_label(IndicatorNg *self, const gchar *label)
 {
-  if (label == NULL || *label == '\0')
+    if (!self->entry.label)
     {
-      if (self->entry.label)
-        gtk_widget_hide (GTK_WIDGET (self->entry.label));
-      return;
+        return;
     }
 
-  gtk_label_set_label (GTK_LABEL (self->entry.label), label);
-  gtk_widget_show (GTK_WIDGET (self->entry.label));
+    const gchar *sLabel = label;
+    guint nSpacing = 3;
+    guint nPadding = 6;
+
+    if (label == NULL || *label == '\0' || !self->entry.image || !gtk_widget_get_visible(GTK_WIDGET(self->entry.image)))
+    {
+        nSpacing = 0;
+        nPadding = 0;
+    }
+
+    GtkWidget *pParent = gtk_widget_get_parent(GTK_WIDGET(self->entry.label));
+    GtkCssProvider *pCssProvider = gtk_css_provider_new();
+    GtkStyleContext *pStyleContext = gtk_widget_get_style_context(GTK_WIDGET(self->entry.label));
+    gtk_style_context_add_provider(pStyleContext, GTK_STYLE_PROVIDER(pCssProvider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gchar *sCss = g_strdup_printf("label{padding-left: %ipx;}", nPadding);
+    gtk_css_provider_load_from_data(pCssProvider, sCss, -1, NULL);
+    g_free(sCss);
+    g_object_unref(pCssProvider);
+    if (GTK_IS_BOX(pParent))
+    {
+        gtk_box_set_spacing(GTK_BOX(pParent), nSpacing);
+    }
+    gtk_label_set_label(GTK_LABEL (self->entry.label), sLabel);
+
+    if (label)
+    {
+        gtk_widget_show(GTK_WIDGET (self->entry.label));
+    }
 }
 
 static void
@@ -947,6 +970,18 @@ indicator_ng_init (IndicatorNg *self)
   g_signal_connect (self->entry.menu, "hide", G_CALLBACK (indicator_ng_menu_hidden), self);
   g_signal_connect (self->entry.menu, "size-allocate", G_CALLBACK (indicator_ng_menu_size_allocate), self);
 
+    GtkCssProvider *pCssProvider = gtk_css_provider_new();
+    GtkStyleContext *pStyleContext = gtk_widget_get_style_context(GTK_WIDGET(self->entry.menu));
+    gtk_style_context_add_provider(pStyleContext, GTK_STYLE_PROVIDER(pCssProvider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_css_provider_load_from_data(pCssProvider, "menu > arrow{min-height: 0; padding: 0; margin: 0;}", -1, NULL);
+
+    GtkWidget *pWindow = gtk_widget_get_parent(GTK_WIDGET(self->entry.menu));
+    pStyleContext = gtk_widget_get_style_context(pWindow);
+    gtk_style_context_add_provider(pStyleContext, GTK_STYLE_PROVIDER(pCssProvider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_css_provider_load_from_data(pCssProvider, "window > decoration {box-shadow: 0 1px 2px rgba(0,0,0,0.2), 0 0 0 1px rgba(0,0,0,0.13);}", -1, NULL);
+
+    g_object_unref(pCssProvider);
+
   /* work around IndicatorObject's warning that the accessible
    * description is missing. We never set it on construction, but when
    * the menu model has arrived on the bus.
